@@ -483,8 +483,8 @@ gui.help <- function(){
             message("Formatting requirements for varietal data files:\n",
                     "------------------------------------------------\n",
                     "A varietal data file looks like a compositional data table, \n",
-                    "with the main difference being that the rows do not correspond \n",
-                    "to samples but to individual grains. The prefixes of the grain \n",
+                    "with the main difference being that the rownames do not correspond \n",
+                    "to samples but to individual grains. The prefixes of these grain \n",
                     "names must contain the sample names. For example:\n",
                     "grain,Pb,Th,U,La,Ce,Pr,Nd,Sr,Y,Lu\n",
                     "ACA_1,16.262,90.9,76.3,615,1972,281.6,1359,319.6,1188,16.87\n",
